Skip to main content
summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorDani Megert2008-03-12 16:53:50 +0000
committerDani Megert2008-03-12 16:53:50 +0000
commita738cc32c89b6f262234fba1b9215708a69f49f5 (patch)
treeb212918df5e42b7dc060630cbabf0adb806d914c /org.eclipse.text/src/org/eclipse/jface/text/templates
parent6cd0fc57a4a9707713ff8c60af330febd3d1e4d6 (diff)
downloadeclipse.platform.text-a738cc32c89b6f262234fba1b9215708a69f49f5.tar.gz
eclipse.platform.text-a738cc32c89b6f262234fba1b9215708a69f49f5.tar.xz
eclipse.platform.text-a738cc32c89b6f262234fba1b9215708a69f49f5.zip
Fixed wrong Javadoc.
Diffstat (limited to 'org.eclipse.text/src/org/eclipse/jface/text/templates')
-rw-r--r--org.eclipse.text/src/org/eclipse/jface/text/templates/Template.java6
-rw-r--r--org.eclipse.text/src/org/eclipse/jface/text/templates/TemplateContextType.java8
2 files changed, 7 insertions, 7 deletions
diff --git a/org.eclipse.text/src/org/eclipse/jface/text/templates/TemplateContextType.java b/org.eclipse.text/src/org/eclipse/jface/text/templates/TemplateContextType.java
index 584a3c2beda..fdbb775944b 100644
--- a/org.eclipse.text/src/org/eclipse/jface/text/templates/TemplateContextType.java
+++ b/org.eclipse.text/src/org/eclipse/jface/text/templates/TemplateContextType.java
@@ -44,7 +44,7 @@ import org.eclipse.jface.text.IDocument;
*/
public class TemplateContextType {
- /** Name of the context type. */
+ /** The id of the context type. */
private /* final */ String fId= null;
/** Variable resolvers used by this content type. */
@@ -77,9 +77,9 @@ public class TemplateContextType {
}
/**
- * Returns the name of the context type.
- *
- * @return the name of the receiver
+ * Returns the id of the context type.
+ *
+ * @return the id of the receiver
*/
public String getId() {
return fId;

Back to the top
diff --git a/org.eclipse.text/src/org/eclipse/jface/text/templates/Template.java b/org.eclipse.text/src/org/eclipse/jface/text/templates/Template.java
index a2b3ca2bc80..041a5defcde 100644
--- a/org.eclipse.text/src/org/eclipse/jface/text/templates/Template.java
+++ b/org.eclipse.text/src/org/eclipse/jface/text/templates/Template.java
@@ -174,12 +174,12 @@ public class Template {
* <code>false</code> otherwise.
*
* @param prefix the prefix (e.g. inside a document) to match
* @param contextTypeName the context type name to match
* @return <code>true</code> if template is enabled and matches the context,
* <code>false</code> otherwise
*/
- public boolean matches(String prefix, String contextTypeName) {
- return fContextTypeId.equals(contextTypeName);
+ public boolean matches(String prefix, String contextTypeId) {
+ return fContextTypeId.equals(contextTypeId);
}
/*
@@ -174,12 +174,12 @@ public class Template {
*
* @param prefix the prefix (e.g. inside a document) to match
- * @param contextTypeName the context type name to match
+ * @param contextTypeId the context type id to match
* @return <code>true</code> if template is enabled and matches the context,
* <code>false</code> otherwise